import React from 'react';
import Card from '@mui/material/Card';
import CardActions from '@mui/material/CardActions';
import CardContent from '@mui/material/CardContent';
import { CardHeader } from '@mui/material';
import Button from '@mui/material/Button';

type WidgetProps = {
    headerTitle?: string,
    actionBtnTitle?: string,
    onActionBtnClicked?: (event: any) => void
    children?: React.ReactNode
}

const Widget: React.FC<WidgetProps> = (props) => {
    const headerTitle = props.headerTitle;
    const actionBtnTitle = props.actionBtnTitle;
    let hasHeaderTitle = (headerTitle && headerTitle.length > 0);

    return (
        <Card sx={{ minWidth: 275 }} variant="outlined">
            {hasHeaderTitle &&
                <CardHeader title={headerTitle} />
            }
            <CardContent>
                {props.children}
            </CardContent>
            {(props.actionBtnTitle !== undefined) &&
                <CardActions>
                    <Button variant="contained" onClick={props.onActionBtnClicked}>{
                        (actionBtnTitle && actionBtnTitle.length > 0) ? actionBtnTitle : "Click"
                    }</Button>
                </CardActions>
            }
        </Card>
    );
}

// Widget.defaultProps = {
//     title: ''
// };

export default Widget;
